@@ -12,6 +12,7 @@ SMS_AUTH_SETTINGS.setdefault("SMS_USER_FIELD", "username")
 SMS_AUTH_SETTINGS.setdefault("SMS_DEBUG", False)
 SMS_AUTH_SETTINGS.setdefault("SMS_DEBUG_CODE", 1111)
 SMS_AUTH_SETTINGS.setdefault("SMS_AUTH_CODE_LEN", 4)
+SMS_AUTH_SETTINGS.setdefault("SMS_AUTH_DEBUG_PHONE_NUMBER", None)
 
 # MESSAGES
 SMS_AUTH_SETTINGS.setdefault("SMS_CODE_NOT_FOUND", "Code not found")
@@ -55,6 +56,7 @@ class Conf:
     SMS_TIMELIFE = SMS_AUTH_SETTINGS.get("SMS_TIMELIFE")
     SMS_USER_FIELD = SMS_AUTH_SETTINGS.get("SMS_USER_FIELD")
     SMS_DEBUG = SMS_AUTH_SETTINGS.get("SMS_DEBUG")
+    SMS_AUTH_DEBUG_PHONE_NUMBER = SMS_AUTH_SETTINGS.get("SMS_AUTH_DEBUG_PHONE_NUMBER")
     SMS_DEBUG_CODE = SMS_AUTH_SETTINGS.get("SMS_DEBUG_CODE")
     SMS_CODE_NOT_FOUND = SMS_AUTH_SETTINGS.get("SMS_CODE_NOT_FOUND")
     SMS_USER_ALREADY_EXIST = SMS_AUTH_SETTINGS.get("SMS_USER_ALREADY_EXIST")
