@@ -22,12 +22,12 @@ class Smsaero(SMSProvider):
             'from': self.conf.SMS_PROVIDER_FROM,
             'type_send': TYPE_SEND,
             'digital': 0,
-            'user': self.conf.SMS_AUTH_PROVIDER_LOGIN,
+            'user': self.conf.SMS_PROVIDER_LOGIN,
             'password': passwd,
             'answer': 'json',
         })
 
-        url = urljoin(self.url, endpoint)
+        url = urljoin(URL, endpoint)
 
         try:
             response = requests.post(url, data=data)
@@ -40,19 +40,19 @@ class Smsaero(SMSProvider):
         return json.loads(response.text)
 
     def send_sms(self):
-        phone = self.to.replace( ' ', '' ) \
+        phone_number = str(self.to).replace( ' ', '' ) \
             .replace( '-', '' ) \
             .replace( '+', '' ) \
             .replace( '(', '' ) \
             .replace( ')', '' )
 
-        match = re.search( '^\+?\d{11}$', phone)
+        match = re.search( '^\+?\d{11}$', phone_number)
         if not match:
             SmsAeroException('Phone number is not valid')
             return
 
         data = {
-            'to': self.to,
+            'to': phone_number,
             'text': self.message,
         }
 
